=== modified file '__init__.py'
--- __init__.py	2005-07-13 22:24:36 +0000
+++ __init__.py	2005-07-16 16:22:04 +0000
@@ -100,8 +100,8 @@
             else:
                 base_rev_id = base_branch.lookup_revision(base_revno)
 
-        outf = codecs.getwriter(user_encoding)(sys.stdout,
-                errors='replace')
+        # outf = codecs.getwriter(user_encoding)(sys.stdout,
+        #         errors='replace')
 
         if starting_rev_id is not None:
             raise BzrCommandError('Specifying the STARTING-REV-ID'
@@ -110,7 +110,7 @@
         gen_changeset.show_changeset(base_branch, base_rev_id,
                 target_branch, target_rev_id,
                 starting_rev_id,
-                to_file=outf, include_full_diff=verbose)
+                to_file=sys.stdout, include_full_diff=verbose)
 
 class cmd_verify_changeset(Command):
     """Read a written changeset, and make sure it is valid.

=== modified file 'common.py'
--- common.py	2005-07-13 22:24:36 +0000
+++ common.py	2005-07-16 16:22:04 +0000
@@ -114,11 +114,11 @@
     >>> encode(u'abcdefg')
     'abcdefg'
     >>> encode(u'a b\\tc\\nd\\\\e')
-    'a b\\\\tc\\\\nd\\\\e'
+    'a b\\tc\\nd\\\\e'
     >>> encode('a b\\tc\\nd\\e')
-    'a b\\\\tc\\\\nd\\\\e'
+    'a b\\tc\\nd\\\\e'
     >>> encode(u'\\u1234\\u0020')
-    '\\\\u1234 '
+    '\\xe1\\x88\\xb4 '
     >>> encode('abcdefg')
     'abcdefg'
     >>> encode(u'')
@@ -126,23 +126,23 @@
     >>> encode('')
     ''
     """
-    return s.encode('unicode_escape')
+    return s.encode('utf-8')
 
 def decode(s):
     """Undo the encode operation, returning a unicode string.
 
     >>> decode('abcdefg')
     u'abcdefg'
-    >>> decode('a b\\\\tc\\\\nd\\\\e')
+    >>> decode('a b\\tc\\nd\\\\e')
     u'a b\\tc\\nd\\\\e'
-    >>> decode('\\\\u1234\\\\u0020')
+    >>> decode('\\xe1\\x88\\xb4 ')
     u'\\u1234 '
     >>> for s in ('test', 'strings'):
     ...   if decode(encode(s)) != s:
     ...     print 'Failed: %r' % s # There should be no failures
 
     """
-    return s.decode('unicode_escape')
+    return s.decode('utf-8')
 
 def format_highres_date(t, offset=0):
     """Format a date, such that it includes higher precision in the

=== modified file 'gen_changeset.py'
--- gen_changeset.py	2005-07-14 00:27:05 +0000
+++ gen_changeset.py	2005-07-16 16:22:04 +0000
@@ -248,11 +248,23 @@
         self.revision_list = [self.target_branch.get_revision(rid) 
                                 for rid in rev_id_list]
 
-    def _write(self, txt, key=None):
+    def _write(self, txt, key=None, encode=True, indent=1):
+        from common import encode as _encode
+        if encode:
+            def write(txt):
+                self.to_file.write(_encode(txt))
+        else:
+            def write(txt):
+                self.to_file.write(txt)
+        if indent > 0:
+            write('#' + (' ' * indent))
         if key:
-            self.to_file.write('# %s: %s\n' % (key, txt))
+            if txt:
+                write('%s: %s\n' % (key, txt))
+            else:
+                write('%s:\n' % key)
         else:
-            self.to_file.write('# %s\n' % (txt,))
+            write('%s\n' % (txt,))
 
     def write_meta_info(self, to_file):
         """Write out the meta-info portion to the supplied file.
@@ -281,13 +293,13 @@
         self.date = format_highres_date(rev.timestamp, offset=rev.timezone)
         write(self.date, key='date')
         if rev.message:
-            self.to_file.write('# message:\n')
+            write('', key='message')
             for line in rev.message.split('\n'):
-                self.to_file.write('#    %s\n' % line)
+                write(txt=line, indent=4)
             self.message = rev.message
 
-        write('')
-        self.to_file.write('\n')
+        write('') # line with just '#'
+        write('', indent=0) # Empty line
 
     def _write_footer(self):
         """Write the stuff that comes after the patches.
@@ -312,23 +324,25 @@
 
     def _write_revisions(self):
         """Not used. Used for writing multiple revisions."""
-        from common import format_highres_date
+        from common import format_highres_date, encode
+
+        write = self._write
 
         for rev in self.revision_list:
             rev_id = rev.revision_id
-            self.to_file.write('# revision: %s\n' % rev_id)
-            self.to_file.write('#    sha1: %s\n' % 
-                self.target_branch.get_revision_sha1(rev_id))
+            write(rev_id, key='revision')
+            write(self.target_branch.get_revision_sha1(rev_id),
+                    key = 'sha1', indent=4)
             if rev.committer != self.committer:
-                self.to_file.write('#    committer: %s\n' % rev.committer)
+                write(rev.committer, key='committer', indent=4)
             date = format_highres_date(rev.timestamp, rev.timezone)
             if date != self.date:
-                self.to_file.write('#    date: %s\n' % date)
+                write(date, key='date', indent=4)
             if rev.inventory_id != rev_id:
-                self.to_file.write('#    inventory id: %s\n' % rev.inventory_id)
-            self.to_file.write('#    inventory sha1: %s\n' % rev.inventory_sha1)
+                write(rev.inventory_id, key='inventory id', indent=4)
+            write(rev.inventory_sha1, key='inventory sha1', indent=4)
             if len(rev.parents) > 0:
-                self.to_file.write('#    parents:\n')
+                write(txt='', key='parents', indent=4)
                 for parent in rev.parents:
                     p_id = parent.revision_id
                     p_sha1 = parent.revision_sha1
@@ -336,16 +350,16 @@
                         warning('Rev id {%s} parent {%s} missing sha hash.'
                                 % (rev_id, p_id))
                         p_sha1 = self.target_branch.get_revision_sha1(p_id)
-                    self.to_file.write('#       %s\t%s\n' % (p_id, p_sha1))
+                    write(p_id + '\t' + p_sha1, indent=7)
             if rev.message and rev.message != self.message:
-                self.to_file.write('#    message:\n')
+                write('', key='message', indent=4)
                 for line in rev.message.split('\n'):
-                    self.to_file.write('#       %s\n' % line)
+                    write(line, indent=7)
 
     def _write_diffs(self):
         """Write out the specific diffs"""
         from bzrlib.diff import internal_diff
-        from common import encode, guess_text_id
+        from common import guess_text_id
         from os.path import join as pjoin
         DEVNULL = '/dev/null'
 
@@ -355,6 +369,8 @@
         rev_id = self.target_rev_id
         tree = self.target_tree
 
+        write = self._write
+
 
         def get_text_id_str(file_id, kind, modified=True):
             """This returns an empty string if guess_text_id == real_text_id.
@@ -365,15 +381,14 @@
                     kind, modified=modified)
             real_id = tree.inventory[file_id].text_id
             if guess_id != real_id:
-                return ' // text-id:' + encode(real_id)
+                return ' // text-id:' + real_id
             else:
                 return ''
 
 
         for path, file_id, kind in self.delta.removed:
             # We don't care about text ids for removed files
-            print >>self.to_file, '*** removed %s %s' % (kind,
-                    encode(path))
+            write('*** removed %s %s' % (kind, path), indent=0)
             if kind == 'file' and self.full_remove:
                 diff_file(pjoin(self.base_label, path),
                           self.base_tree.get_file(file_id).readlines(),
@@ -382,10 +397,9 @@
                           self.to_file)
     
         for path, file_id, kind in self.delta.added:
-            print >>self.to_file, '*** added %s %s // file-id:%s%s' % (kind,
-                    encode(path),
-                    encode(file_id),
-                    get_text_id_str(file_id, kind))
+            write('*** added %s %s // file-id:%s%s' % (kind,
+                    path, file_id, get_text_id_str(file_id, kind)),
+                    indent=0)
             if kind == 'file':
                 diff_file(DEVNULL,
                           [],
@@ -394,9 +408,10 @@
                           self.to_file)
     
         for old_path, new_path, file_id, kind, text_modified in self.delta.renamed:
-            print >>self.to_file, '*** renamed %s %s // %s%s' % (kind,
-                    encode(old_path), encode(new_path),
-                    get_text_id_str(file_id, kind, modified=text_modified))
+            write('*** renamed %s %s // %s%s' % (kind,
+                    old_path, new_path,
+                    get_text_id_str(file_id, kind, modified=text_modified)),
+                    indent=0)
             if self.full_rename and kind == 'file':
                 diff_file(pjoin(self.base_label, old_path),
                           self.base_tree.get_file(file_id).readlines(),
@@ -416,8 +431,9 @@
                               self.to_file)
     
         for path, file_id, kind in self.delta.modified:
-            print >>self.to_file, '*** modified %s %s%s' % (kind,
-                    encode(path), get_text_id_str(file_id, kind))
+            write('*** modified %s %s%s' % (kind,
+                    path, get_text_id_str(file_id, kind)),
+                    indent=0)
             if kind == 'file':
                 diff_file(pjoin(self.base_label, path),
                           self.base_tree.get_file(file_id).readlines(),

=== modified file 'read_changeset.py'
--- read_changeset.py	2005-07-15 19:00:27 +0000
+++ read_changeset.py	2005-07-16 16:22:04 +0000
@@ -342,8 +342,8 @@
 
     def _read_header(self):
         """Read the bzr header"""
-        import common
-        header = common.get_header()
+        from common import decode, get_header, header_str
+        header = get_header()
         found = False
         for line in self._next():
             if found:
@@ -351,15 +351,15 @@
                 if line == '#\n':
                     line = '# \n'
                 if (line[:2] != '# ' or line[-1:] != '\n'
-                        or line[2:-1] != header[0]):
+                        or decode(line[2:-1]) != header[0]):
                     raise MalformedHeader('Found a header, but it'
                         ' was improperly formatted')
                 header.pop(0) # We read this line.
                 if not header:
                     break # We found everything.
             elif (line[:1] == '#' and line[-1:] == '\n'):
-                line = line[1:-1].strip()
-                if line[:len(common.header_str)] == common.header_str:
+                line = decode(line[1:-1].strip())
+                if line[:len(header_str)] == header_str:
                     if line == header[0]:
                         found = True
                     else:
@@ -379,9 +379,10 @@
     def _read_next_entry(self, line, indent=1):
         """Read in a key-value pair
         """
+        from common import decode
         if line[:1] != '#':
             raise MalformedHeader('Bzr header did not start with #')
-        line = line[1:-1] # Remove the '#' and '\n'
+        line = decode(line[1:-1]) # Remove the '#' and '\n'
         if line[:indent] == ' '*indent:
             line = line[indent:]
         if not line:
@@ -427,6 +428,7 @@
         This detects the end of the list, because it will be a line that
         does not start properly indented.
         """
+        from common import decode
         values = []
         start = '#' + (' '*indent)
 
@@ -434,7 +436,7 @@
             return values
 
         for line in self._next():
-            values.append(line[len(start):-1])
+            values.append(decode(line[len(start):-1]))
             if self._next_line is None or self._next_line[:len(start)] != start:
                 break
         return values
@@ -445,6 +447,7 @@
 
         :return: action, lines, do_continue
         """
+        from common import decode
         #mutter('_read_one_patch: %r' % self._next_line)
         # Peek and see if there are no patches
         if self._next_line is None or self._next_line[:1] == '#':
@@ -458,7 +461,7 @@
                     raise MalformedPatches('The first line of all patches'
                         ' should be a bzr meta line "***"'
                         ': %r' % line)
-                action = line[4:-1]
+                action = decode(line[4:-1])
             if self._next_line is not None and self._next_line[:3] == '***':
                 return action, lines, True
             elif self._next_line is None or self._next_line[:1] == '#':
@@ -543,11 +546,11 @@
             if len(info) < 2:
                 raise BzrError('renamed action lines need both a from and to'
                         ': %r' % extra)
-            old_path = decode(info[0])
+            old_path = info[0]
             if info[1][:3] == '=> ':
-                new_path = decode(info[1][3:])
+                new_path = info[1][3:]
             else:
-                new_path = decode(info[1])
+                new_path = info[1]
 
             file_id = tree.path2id(new_path)
             if len(info) > 2:
@@ -556,7 +559,7 @@
                 text_id = get_text_id(None, file_id, kind)
             tree.note_rename(old_path, new_path)
             if lines:
-                tree.note_patch(new_path, ''.join(lines), text_id)
+                tree.note_patch(new_path, ''.join(lines))
 
         def removed(kind, extra, lines):
             info = extra.split(' // ')
@@ -565,7 +568,7 @@
                 # given for removed entries
                 raise BzrError('removed action lines should only have the path'
                         ': %r' % extra)
-            path = decode(info[0])
+            path = info[0]
             tree.note_deletion(path)
 
         def added(kind, extra, lines):
@@ -576,11 +579,11 @@
             elif len(info) > 3:
                 raise BzrError('add action lines have fewer than 3 entries.'
                         ': %r' % extra)
-            path = decode(info[0])
+            path = info[0]
             if info[1][:8] != 'file-id:':
                 raise BzrError('The file-id should follow the path for an add'
                         ': %r' % extra)
-            file_id = decode(info[1][8:])
+            file_id = info[1][8:]
 
             tree.note_id(file_id, path, kind)
             if kind == 'directory':
@@ -596,7 +599,7 @@
             if len(info) < 1:
                 raise BzrError('modified action lines have at least'
                         'the path in them: %r' % extra)
-            path = decode(info[0])
+            path = info[0]
 
             file_id = tree.path2id(path)
             if len(info) > 1:

=== modified file 'testchangeset.py'
--- testchangeset.py	2005-07-16 04:11:44 +0000
+++ testchangeset.py	2005-07-16 16:22:04 +0000
@@ -276,7 +276,8 @@
         self.assertEqual(cset_txt.readline(), '# \n')
 
         rev = self.b1.get_revision(rev_id)
-        self.assertEqual(cset_txt.readline(), '# committer: %s\n' % rev.committer)
+        self.assertEqual(cset_txt.readline().decode('utf-8'),
+                u'# committer: %s\n' % rev.committer)
 
         open(',,cset', 'wb').write(cset_txt.getvalue())
         cset_txt.seek(0)
@@ -414,6 +415,7 @@
                 , 'b1/dir/'
                 , 'b1/dir/filein subdir.c'
                 , 'b1/dir/WithCaps.txt'
+                , 'b1/dir/trailing space '
                 , 'b1/sub/'
                 , 'b1/sub/sub/'
                 , 'b1/sub/sub/nonempty.txt'
@@ -426,6 +428,7 @@
                 , 'dir'
                 , 'dir/filein subdir.c'
                 , 'dir/WithCaps.txt'
+                , 'dir/trailing space '
                 , 'sub'
                 , 'sub/sub'
                 , 'sub/sub/nonempty.txt'
@@ -464,6 +467,31 @@
         cset = self.get_valid_cset('a@cset-0-2', 'a@cset-0-4', auto_commit=True)
         cset = self.get_valid_cset('a@cset-0-3', 'a@cset-0-4', auto_commit=True)
 
+        # Modified files
+        open('b1/sub/dir/WithCaps.txt', 'ab').write('\nAdding some text\n')
+        #open('b1/sub/dir/trailing space ', 'ab').write('\nAdding some\nDOS format lines\n')
+        #self.b1.rename_one('sub/dir/trailing space ', 'sub/start and end space')
+        self.b1.commit('Modified files', rev_id='a@cset-0-5')
+        cset = self.get_valid_cset('a@cset-0-4', 'a@cset-0-5')
+        cset = self.get_valid_cset('a@cset-0-4', 'a@cset-0-5', auto_commit=True)
+        cset = self.get_valid_cset(None, 'a@cset-0-5', auto_commit=True)
+
+        # Handle international characters
+        f = open(u'b1/with Dod\xe9', 'wb')
+        f.write((u'A file\n'
+            u'With international man of mystery\n'
+            u'William Dod\xe9\n').encode('utf-8'))
+        self.b1.add([u'with Dod\xe9'])
+        # BUG: (sort of) You must set verbose=False, so that python doesn't try
+        #       and print the name of William Dode as part of the commit
+        self.b1.commit(u'i18n commit from William Dod\xe9', rev_id='a@cset-0-6',
+                committer=u'William Dod\xe9', verbose=False)
+        cset = self.get_valid_cset('a@cset-0-5', 'a@cset-0-6')
+        cset = self.get_valid_cset('a@cset-0-5', 'a@cset-0-6', auto_commit=True)
+        cset = self.get_valid_cset(None, 'a@cset-0-6', auto_commit=True)
+
+
+
 TEST_CLASSES = [
     CTreeTester,
     CSetTester

